﻿using UnityEngine;
using System.Collections;

public class GameManager : MonoBehaviour {

	public Material backgroundMaterial;
	public static GameManager Instance;
	public AudioClip gameMusic;

	public GameObject[] obstacles;
	public Button[] buttons;
	public GUIText gameTimerText;
	private float gameTimer = 0;
	private bool timerRunning = false;
	private int currentObstacle = 0;

	void Awake()
	{
		Instance = this;
		GameObject obj = new GameObject("BackgroundPlane");
		MeshRenderer render = obj.AddComponent<MeshRenderer>();
		MeshFilter filter = obj.AddComponent<MeshFilter>();
		filter.mesh = MeshFactory.CreatePlane(80.0f, 60.0f, 1.0f);
		render.material = backgroundMaterial;
		obj.transform.position = new Vector3(-10.0f, 0.0f, 10.0f);
		foreach (Button b in FindObjectsOfType<Button>()) {
			b.transform.Find("trigger").GetComponent<SpriteRenderer>().color = new Color(0.5f, 0.5f, 0.5f);
		}
		buttons[0].transform.Find("trigger").GetComponent<SpriteRenderer>().color = Color.white;
		buttons[0].isGoal = true;
	}

	public void Update()
	{
		if (timerRunning) gameTimer += Time.deltaTime;
		int seconds = Mathf.RoundToInt(gameTimer);
		int minutes = seconds / 60;
		seconds = seconds % 60;
		gameTimerText.text = (minutes >= 10 ? "" + minutes : "0" + minutes) + (seconds >= 10 ? ":" + seconds : ":0" + seconds);
	}

	public void NextObstacle()
	{
		if (currentObstacle >= obstacles.Length) return;
		MoveObject mo = obstacles[currentObstacle].GetComponent<MoveObject>();
		if (mo != null) mo.StartMoving();
		LaserTurret lt = obstacles[currentObstacle].GetComponent<LaserTurret>();
		if (lt != null) lt.SetActive(true);
		currentObstacle++;
		if (currentObstacle >= buttons.Length) {
			timerRunning = false;
			audio.Stop();
			gameTimerText.text = gameTimerText.text + "!!";
			return;
		}
		buttons[currentObstacle].isGoal = true;
		buttons[currentObstacle].transform.Find("trigger").GetComponent<SpriteRenderer>().color = Color.white;
		if (currentObstacle == 1) {
			timerRunning = true;
			gameTimer = 0;
			audio.clip = gameMusic;
			audio.Play();
		}
	}
	
}
