﻿using UnityEngine;
using System.Collections;

public class LaserTurret : MonoBehaviour {

	public float rotateSpeed = 0.0f;
	public bool limitAngle = false;
	public float angleLeft = -140.0f;
	public float angleRight = -30.0f;

	public bool pulsate = false;
	public float pulseOnTime = 100.0f;
	public float pulseOffTime = 0.0f;
	public float pulseTimer = 0.0f;
	private bool pulseStateActive = true;
	
	private Transform laser;
	private Transform fizzle;
	private static int laserLayer;

	public bool laserActive = true;

	// Use this for initialization
	void Start() {
		laser = transform.Find("laser");
		fizzle = transform.Find("fizzle");
		laser.localScale = new Vector3(0.0f, 1.0f, 1.0f);
		laserLayer = LayerMask.GetMask("Walls", "Player");
	}
	
	// Update is called once per frame
	void FixedUpdate() {
		float angle = transform.localEulerAngles.z;
		if (limitAngle) {
			if (rotateSpeed > 0.0f) {
				angle = Mathf.MoveTowardsAngle(angle, angleRight, rotateSpeed * Time.deltaTime);
				if (Utilities.AnglesEqual(angle, angleRight)) {
					rotateSpeed = -Mathf.Abs(rotateSpeed);
				}
			} else {
				angle = Mathf.MoveTowardsAngle(angle, angleLeft, Mathf.Abs(rotateSpeed) * Time.deltaTime);
				if (Utilities.AnglesEqual(angle, angleLeft)) {
					rotateSpeed = Mathf.Abs(rotateSpeed);
				}
			}
		} else {
			angle += rotateSpeed * Time.deltaTime;
		}
		float rot = angle - transform.localEulerAngles.z;
		transform.RotateAround(transform.TransformPoint(new Vector3(-0.2f, 0.0f, 0.0f)), Vector3.forward, rot);

		if (pulsate) {
			pulseTimer = Mathf.MoveTowards(pulseTimer, 0.0f, Time.deltaTime);
			if (pulseTimer < Mathf.Epsilon) {
				pulseStateActive = !pulseStateActive;
				pulseTimer = pulseStateActive ? pulseOnTime : pulseOffTime;
			}
		}

		float width = laser.localScale.y;
		width = Mathf.MoveTowards(width, pulseStateActive ? 1.0f : 0.0f, Time.deltaTime * 10.0f);

		if (laserActive && width > Mathf.Epsilon) {
			RaycastHit2D hitInfo = Physics2D.Raycast(
				transform.position, transform.right, 1000.0f, laserLayer
			);
			if (hitInfo.collider != null) {
				laser.localScale = new Vector3(1000.0f * hitInfo.fraction, width, 1.0f);
				laser.localPosition = new Vector3(1000.0f * hitInfo.fraction / 2.0f, 0.0f, 0.0f);
				fizzle.localPosition = new Vector3(1000.0f * hitInfo.fraction, 0.0f, 0.0f);
				fizzle.localScale = new Vector3(width, width, 1.0f);
			} else {
				laser.localScale = new Vector3(1000.0f, width, 1.0f);
				laser.localPosition = new Vector3(500.0f, 0.0f, 0.0f);
				fizzle.localPosition = new Vector3(1000.0f * hitInfo.fraction, 0.0f, 0.0f);
				fizzle.localScale = new Vector3(width, width, 1.0f);
			}

			Player player = hitInfo.collider.GetComponent<Player>();
			if (player != null && width > 0.99f) {
				player.Die();
			}
		} else {
			laser.localScale = new Vector3(0.0f, 0.0f, 1.0f);
			laser.localPosition = Vector3.zero;
			fizzle.localScale = new Vector3(0.0f, 0.0f, 1.0f);
		}
	}

	public void SetActive(bool active)
	{
		laserActive = active;
	}
}
