﻿#define DEBUG

using UnityEngine;

public static class Utilities
{

	public static bool AnglesEqual(float a1, float a2)
	{
		float a = Mathf.Abs(a1 - a2) % 360;
		if (a > 180) a = 360 - a;
		return a < 0.05f;
	}

	// Swap two values
	public static void Swap<T>(ref T lhs, ref T rhs)
	{
		T temp = lhs;
		lhs = rhs;
		rhs = temp;
	}

	[System.Diagnostics.Conditional("DEBUG")]
	public static void Assert(bool condition)
	{
		if (!condition) {
			UnityEngine.Debug.Break();
			throw new System.Exception();
		}
	}
	
	public static void DebugRect(Rect r) { DebugRect(r, Color.white); }
	public static void DebugRect(Rect r, Color clr, float duration=0.0f)
	{
		Debug.DrawLine(new Vector2(r.xMin, r.yMin), new Vector2(r.xMin, r.yMax), clr, duration);
		Debug.DrawLine(new Vector2(r.xMin, r.yMax), new Vector2(r.xMax, r.yMax), clr, duration);
		Debug.DrawLine(new Vector2(r.xMax, r.yMax), new Vector2(r.xMax, r.yMin), clr, duration);
		Debug.DrawLine(new Vector2(r.xMax, r.yMin), new Vector2(r.xMin, r.yMin), clr, duration);
	}
	public static void DebugRect(Bounds b) { DebugRect(b, Color.white); }
	public static void DebugRect(Bounds b, Color clr, float duration=0.0f)
	{
		Debug.DrawLine(new Vector2(b.min.x, b.min.y), new Vector2(b.min.x, b.max.y), clr, duration);
		Debug.DrawLine(new Vector2(b.min.x, b.max.y), new Vector2(b.max.x, b.max.y), clr, duration);
		Debug.DrawLine(new Vector2(b.max.x, b.max.y), new Vector2(b.max.x, b.min.y), clr, duration);
		Debug.DrawLine(new Vector2(b.max.x, b.min.y), new Vector2(b.min.x, b.min.y), clr, duration);
	}

	public static void DebugPoint(Vector3 point) { DebugPoint(point, Color.white); }
	public static void DebugPoint(Vector3 point, Color clr, float duration=0.0f)
	{
		Debug.DrawLine(point + new Vector3(0.1f, 0.0f), point + new Vector3(-0.1f, 0.0f), clr, duration);
		Debug.DrawLine(point + new Vector3(0.0f, 0.1f), point + new Vector3(0.0f, -0.1f), clr, duration);
	}

}